@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-07-06'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2015-07-08'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,6 +34,7 @@ has config_filename => (is=>'rw');
 has ssl_verify_hostname => (is=>'rw');
 has load_modules => (is=>'rw');
 has snippet_before_instantiate_cmdline => (is=>'rw');
+has skip_format => (is=>'rw');
 
 sub gather_files {
     # we actually don't generate scripts in this phase but in the later stage
@@ -94,6 +95,7 @@ sub munge_files {
             subcommands_from_package_functions => $self->subcommands_from_package_functions,
             (include_package_functions_match => $self->include_package_functions_match) x !!$self->include_package_functions_match,
             (exclude_package_functions_match => $self->exclude_package_functions_match) x !!$self->exclude_package_functions_match,
+            skip_format => $self->skip_format ? 1:0,
         );
         $self->log_fatal("Failed generating $scriptname: $res->[0] - $res->[1]")
             unless $res->[0] == 200;
@@ -130,7 +132,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.17 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-06.
+This document describes version 0.18 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-08.
 
 =head1 SYNOPSIS
 
@@ -274,6 +276,10 @@ Comma-separated string, extra modules to load in the generated script.
 
 This is like the configuration, but per-script.
 
+=head2 skip_format => bool
+
+Passed to Perinci::CmdLine object construction code.
+
 =head1 SEE ALSO
 
 L<Rinci>
@@ -289,7 +295,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
 
 =head1 BUGS
 
